@@ -69,6 +69,8 @@ MainThemeList = {
 
 '''
     指定特定签底对应表，应指定对应图片路径（./resource/img后）；random仅为标识
+    Key-Value: 签底别名-图片路径 
+    SpecificTypeList 在dev及v0.2.3+已移除，改为json数据保存及读取
 '''
 
 def copywriting() -> str:
